#!/usr/bin/env python3

import argparse
import gitlab
import os

parser = argparse.ArgumentParser(description='Create GitLab Issue')
parser.add_argument('title', action='store',
                    help='The title of the issue')
parser.add_argument('--project', '-p', action='store', default='paragon/devop',
                    help='namespace/projectname or project ID')
parser.add_argument('--description', '-d', action='store', default=None,
                    help='Description')
parser.add_argument('--assign', '-a', action='store', default=None,
                    help='User name to whom this should be assigned')
parser.add_argument('--label', '-l', action='store', default=None,
                    help='Labels, separated by comma')
args = parser.parse_args()

g = gitlab.Gitlab.from_config('lakedrops', [os.path.expanduser('~/.gitlab.cfg')])  # type: gitlab
g.auth()

project = g.projects.get(args.project)  # type: gitlab.Project

if not project:
    exit(1)

arguments = {"title": args.title,
             "description": args.description
             }
if args.label:
    arguments['label'] = ','.split(args.label)

if args.assign:
    assignee = g.users.list(username=args.assign)[0]
    if assignee:
        arguments['assignee_id'] = assignee.id

issue = project.issues.create(arguments)  # type: gitlab.Issue
print(issue.web_url)
